@@ -28,6 +28,8 @@
 #include <gio/gio.h>
 #include <xfconf/xfconf.h>
 
+#include "theme-css.h"
+
 G_BEGIN_DECLS
 
 #define XFDASHBOARD_TYPE_APPLICATION				(xfdashboard_application_get_type())
@@ -73,11 +75,13 @@ XfdashboardApplication* xfdashboard_application_get_default(void);
 gboolean xfdashboard_application_is_daemonized(XfdashboardApplication *self);
 gboolean xfdashboard_application_is_suspended(XfdashboardApplication *self);
 
-XfconfChannel* xfdashboard_application_get_xfconf_channel(void);
-
 void xfdashboard_application_quit(void);
 void xfdashboard_application_quit_forced(void);
 
+XfconfChannel* xfdashboard_application_get_xfconf_channel(void);
+
+XfdashboardThemeCSS* xfdashboard_application_get_theme(void);
+
 G_END_DECLS
 
 #endif	/* __XFDASHBOARD_APPLICATION__ */
