@@ -31,6 +31,10 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "theme-css.h" */
+GType xfdashboard_theme_css_error_enum_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_THEME_CSS_ERROR_ENUM	(xfdashboard_theme_css_error_enum_get_type())
+
 /* enumerations from "types.h" */
 GType xfdashboard_view_mode_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_VIEW_MODE	(xfdashboard_view_mode_get_type())
